use strict;
use warnings;
use Test::More tests => 13;
BEGIN { use_ok('SMS::Send::NANP::Twilio') };

my $ws = SMS::Send::NANP::Twilio->new(username=>'myusername', password=>'mypassword', from=>'myfrom', sid=>'');

isa_ok($ws, 'SMS::Send::NANP::Twilio');
can_ok($ws, 'username');
can_ok($ws, 'password');
can_ok($ws, 'url');
can_ok($ws, 'from');
can_ok($ws, 'sid');
can_ok($ws, 'uat');
isa_ok($ws->uat, 'HTTP::Tiny');

is($ws->username, 'myusername', 'username');
is($ws->password, 'mypassword', 'password');
is($ws->from, 'myfrom', 'from');
ok(!$ws->sid, 'sid');
